#
# spec file for package jack
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define buildoc 1
%define debug_package_requires %{name} = %{version}-%{release}
# Switch the --dbus on and off, on = 1
%define wdbus 1
%define sonum 0
Name:           jack
Version:        1.9.22
Release:        2.2
#to_be_filled_by_service
Summary:        Jack-Audio Connection Kit
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          System/Sound Daemons
URL:            https://jackaudio.org/
Source0:        https://github.com/jackaudio/jack2/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        baselibs.conf
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  python3-base
BuildRequires:  readline-devel
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(celt) >= 0.5.0
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(eigen3) >= 3.1.2
BuildRequires:  pkgconfig(expat)
BuildRequires:  pkgconfig(flac)
BuildRequires:  pkgconfig(flac++)
BuildRequires:  pkgconfig(libffado) >= 2.0.1.2040
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(ogg)
BuildRequires:  pkgconfig(opus)
BuildRequires:  pkgconfig(samplerate)
BuildRequires:  pkgconfig(sndfile)
Requires:       jack-dbus
Conflicts:      jack-daemon
Provides:       jack-audio-connection-kit
Provides:       jack-daemon
Provides:       jack2 = %{version}
Obsoletes:      jack2 < %{version}

%description
JACK is system for handling real-time, low latency audio
(and MIDI). It runs on GNU/Linux, Solaris, FreeBSD, OS X and
Windows (and can be ported to other POSIX-conformant
platforms). It can connect a number of different
applications to an audio device, as well as allowing them to
share audio between themselves. Its clients can run in their
own processes (ie. as normal applications), or can they can
run within the JACK server (ie. as a "plugin"). JACK also
has support for distributing audio processing across a
network, both fast & reliable LANs as well as slower, less
reliable WANs.

%if 0%{?wdbus} == 1
%package dbus
Summary:        Jack Audio Connection Kit D-Bus support
Group:          System/Sound Daemons
Requires:       jack-daemon

%description dbus
This package contains the D-Bus support for JACK
(Jack Audio ConnectionKit).
%endif

%package -n libjack%{sonum}
Summary:        Jack Audio Connection Kit Library
Group:          System/Libraries
Provides:       libjack = %{version}
Obsoletes:      libjack < %{version}
Provides:       libjack2

%description -n libjack%{sonum}
This package contains the library to access JACK
(Jack Audio ConnectionKit).

%package -n libjacknet%{sonum}
Summary:        Jack Audio Connection Kit Library
Group:          System/Libraries
# libjacknet was packaged with libjack0 prior to 1.9.12
Conflicts:      libjack0 < 1.9.12
Provides:       libjack0:%{_libdir}/libjacknet.so.%{sonum}*

%description -n libjacknet%{sonum}
This package contains the library to access JACK
(Jack Audio ConnectionKit) network functions.

%package -n libjackserver%{sonum}
Summary:        Jack Audio Connection Kit Library
Group:          System/Libraries
# libjackserver was packaged with libjack0 prior to 1.9.12
Conflicts:      libjack0 < 1.9.12
Provides:       libjack0:%{_libdir}/libjackserver.so.%{sonum}*

%description -n libjackserver%{sonum}
This package contains the library to access JACK
(Jack Audio ConnectionKit) server functions.

%package -n libjack-devel
Summary:        Development package for jack
Group:          Development/Libraries/C and C++
Requires:       libjack%{sonum} = %{version}
Requires:       libjacknet%{sonum} = %{version}
Requires:       libjackserver%{sonum} = %{version}
Requires:       pkgconfig
Provides:       jack-audio-connection-kit-devel
Provides:       jack-devel
Provides:       libjack2-devel = %{version}
Obsoletes:      libjack2-devel < %{version}

%description -n libjack-devel
This package contains the files needed to compile programs that
communicate with jack clients/servers.

%prep
%setup -q -n %{name}2-%{version}
%autopatch -p1

#Change python script headers to python3
for i in `grep -rl "%{_bindir}/env python"`;do sed -i '1s/^#!.*/#!\/usr\/bin\/python3/' ${i} ;done

%build
%define _lto_cflags %{nil}
export CFLAGS="%{optflags} -ggdb -fPIC"
export CXXFLAGS="$CFLAGS"

./waf -v %{?_smp_mflags} \
  --prefix=%{_prefix} \
  --libdir=%{_libdir} \
  --classic \
%if 0%{?wdbus} == 1
  --dbus \
%endif
  --firewire \
%if %{buildoc} == 1
  --doxygen \
%endif
  --alsa \
  --ports=1024 \
  --enable-pkg-config-dbus-service-dir \
  --mandir=%{_mandir}/man1 \
  configure

./waf -v %{?_smp_mflags} build

%install
./waf -j1 install --destdir=%{buildroot}
mkdir -p %{buildroot}%{_docdir}
%if %{buildoc} == 1
mv %{buildroot}%{_datadir}/jack-audio-connection-kit %{buildroot}%{_docdir}
%endif

%fdupes -s %{buildroot}%{_docdir}

%post -n libjack%{sonum} -p /sbin/ldconfig
%postun -n libjack%{sonum} -p /sbin/ldconfig
%post -n libjacknet%{sonum} -p /sbin/ldconfig
%postun -n libjacknet%{sonum} -p /sbin/ldconfig
%post -n libjackserver%{sonum} -p /sbin/ldconfig
%postun -n libjackserver%{sonum} -p /sbin/ldconfig

%files
%doc ChangeLog.rst README*
%license COPYING
%{_mandir}/man1/*
%{_bindir}/*
%exclude %{_bindir}/jackdbus
%exclude %{_bindir}/jack_control
%dir %{_libdir}/%{name}
%{_libdir}/%{name}/%{name}_alsa.so
%{_libdir}/%{name}/%{name}_dummy.so
%{_libdir}/%{name}/%{name}_net.so
%{_libdir}/%{name}/netmanager.so*
%{_libdir}/%{name}/profiler.so*
%{_libdir}/%{name}/netadapter.so*
%{_libdir}/%{name}/audioadapter.so*
%{_libdir}/%{name}/%{name}_loopback.so*
%{_libdir}/%{name}/%{name}_netone.so*
%{_libdir}/%{name}/jack_alsarawmidi.so
%{_libdir}/%{name}/%{name}_firewire.so
%{_libdir}/%{name}/%{name}_proxy.so

%if 0%{?wdbus} == 1
%files dbus
%{_bindir}/jackdbus
%{_bindir}/jack_control
%{_datadir}/dbus-1/services/org.jackaudio.service
%endif

%files -n libjack%{sonum}
%{_libdir}/libjack.so.%{sonum}*

%files -n libjacknet%{sonum}
%{_libdir}/libjacknet.so.%{sonum}*

%files -n libjackserver%{sonum}
%{_libdir}/libjackserver.so.%{sonum}*

%files -n libjack-devel
%{_libdir}/lib*.so
%{_libdir}/pkgconfig/*
%{_includedir}/%{name}
%if %{buildoc} == 1
%dir %{_docdir}/jack-audio-connection-kit
%doc %{_docdir}/jack-audio-connection-kit/*
%endif

%changelog
* Fri May 19 2023 Alexei Sorokin <sor.alexei@meowr.ru>
- Provide jack-daemon as an implementation-agnostic virtual name.
- Split jackdbus into a separate jack-dbus package.
* Thu Mar 30 2023 Dirk Müller <dmueller@suse.com>
- update to 1.9.22:
  * The waf autooption ``--example-tools`` has been removed.
  * The example clients and tools are no longer part of the jack2
    project.
  * Drop dependencies that were only used for example clients and
    tools (readline, sndfile and zita libs)
  * Fix build with python3.11+
  * Fix compatibility with macOS 12+
  * Fix ringbuffer thread safety on ARM
* Wed Apr 20 2022 Dirk Müller <dmueller@suse.com>
- update to 1.9.21:
  * Add shell mode to ``jack_control`` (executes commands from stdin until EOF)
  * The waf autooption ``--example-tools`` introduced in 1.9.20 is now off by default,
    To get the previous behavior back pass ``--example-tools`` during build.
    This flag (and the related tools and their code) are going to be removed in the next release.
  * Fix alignas() on non-packed architectures
  * Fix build of jack-example-tools man pages (1.9.20 regression)
  * Fix compatibility with macOS 12
  * Fix missing symbols from jack client library (error and info callback pointers)
  * Fix potential memory corruption in midi_latency_test tool
  * Fix JackWeakAPI on Windows
  * Use predefined variables in pkg-config file (required for mingw)
* Tue Mar  1 2022 Antonio Larrosa <alarrosa@suse.com>
- Disable the build of example-tools which are now built in a
  separate jack-example-tools package.
- update to 1.9.20:
  * Add waf autooption --example-tools to allow optional build of
    executables, libraries and man pages provided by
    jack-example-tools (the files are built by default). Building
    and installing the additional files can be disabled by using
  - -example-tools=no or --no-example-tools.
  * Fix 32-bit support in ALSA driver
  * Fix incomplete ASIO support on Windows
  * Fix metadata usage with multiple users
  * Fix netsource tool missing on Windows
  * Fix semaphore usage on macOS
  * Official FreeBSD support
* Sat Oct 16 2021 Dirk Müller <dmueller@suse.com>
- drop 0001-Fix-compilation-of-documentation.patch (upstream).
- update to 1.9.19:
  * Add jack_position_t::tick_double, and flags around it
  * Add zalsa "-w" argument to wait for soundcard to be available
  * Bump internal protocol version to 9 (due to struct alignment)
  * Fix alignment of fields for atomic accesses
  * Fix build for platforms needing __STDC_FORMAT_MACROS
  * Fix compilation of documentation
* Sat Apr 17 2021 Dirk Müller <dmueller@suse.com>
- update to 1.9.18:
  * Add zalsa_in/out as internal client (based on zita-a2j/j2a and jack1 code)
  * Fix jack_midi_dump deadlock on close after the jack server is restarted
  * Fix interrupt signal for linux futex waits
  * Fix usage of meta-data in official macOS builds (private DB errors)
  * Log error message when cleaning previous DB (macOS and Windows)
* Sun Jan 24 2021 Dirk Müller <dmueller@suse.com>
- update to 1.9.17:
  * Fix jack_control stopping after first command iteration
  * Fix registry keys for Windows, add 32bit compat ones on 64bit
  * Fix library compat/current version under macOS
  * Fix return codes of jackd on success
  * Ignore DB_VERSION_MISMATCH error on windows, it is expected
  * Remove old workaround for asio4all, as it breaks with jack-router
* Mon Jan 18 2021 Dave Plater <davejplater@gmail.com>
- Removed portaudio build dependency to prevent cycles
* Thu Jan 14 2021 ecsos <ecsos@opensuse.org>
- Update to 1.9.16
  - Fix/revert a change in how meta-data definitions were exposed
    (regression in 1.9.15)
  - Remove jack-router Windows code from the repository
- Changes from 0.9.15
  - Automated builds for macOS and Windows
    (see jackaudio/jack2-releases repository)
  - Adapt wscript Windows build configuration to match old v1.9.11
    installer
  - Bump maximum default number of clients and ports
    (now 256 clients and 2048 ports)
  - Delete various macOS and Windows-related files from the source
    code (no longer relevant)
  - Mark JACK-Session as deprecated, please use NSM instead
  - Remove unnecessary GPL include from LGPL code
  - Split example-clients and tools, as done in JACK1 many years
    ago (WIP)
  - Write Windows registry key during installation, so 3rd parties
    can find jackd.exe (as HKLM\Software\JACK\Location)
  - jack_control: Fix handling of dbus bytes
  - jack_control: Return a proper exit status on DBus exception
  - jack_property: Fix possible crash with "-l" argument usage
  - jack_wait: Add client name option -n/--name
  - Fix compilation of documentation
  - Fix compilation of mixed mode with meta-data enabled
  - Fix compilation with mingw
  - Fix client-side crash if initial meta-data DB setup fails
  - Fix macOS semaphore usage, so it works again
  - Several fixes for Windows
  - Several minor fixes and grammar corrections
* Mon May  4 2020 Dave Plater <davejplater@gmail.com>
- Deleted af6c00ab09428e79.patch and replaced with more eloquently
  named git patch  0001-Fix-compilation-of-documentation.patch
- Closed boo#1141762 disabling LTO is no longer needed and there
  have been no crashes since someone quietly enabled it.
* Wed Feb  5 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to 1.9.14
  + Fix ARM build
  + Fix mixed mode build when meta-data is enabled
  + Fix blocking DBus device reservation, so it plays nice with
    others (like PipeWire)
  + Use python3 for the waf build scripts
- Remove upstreamed 0001-fix-complation-on-arm.patch
- Fix documentation generation, add upstream af6c00ab09428e79.patch
- Spec file cleanup:
  + Drop obsolete and duplicate dos2unix invocations, drop build
    dependency.
  + Remove conditionals for EOLed distributions
  + Run %%fdupes inside %%buildroot, not system root
  + Remove hardcoded SOURCE_DATE_EPOCH
- Use proper Conflicts/Provides for libjacketnet/server after
  package split in 1.9.12.
* Tue Oct 29 2019 Tom Mbrt <tom.mbrt@googlemail.com>
- Update to 1.9.13
  * Meta-data API implementation. (and a few tools updated with support for it)
  * Correct GPL licence to LGPL for files needed to build libjack.
  * Remove FreeBoB backend (superseded by FFADO).
  * define JACK_LIB_EXPORT, useful for internal clients.
  * Mark jack_midi_reset_buffer as deprecated.
  * Add example systemd unit file
  * Signal to systemd when jackd is ready.
  * Set "seq" alsa midi driver to maximum resolution possible.
  * Fix loading internal clients from another internal client.
- Delete the following patches, as they were fixed upstream:
  * 0001-Make-jack_control-python2-3-compatible.patch
  * fix-mmap-return-value-check.patch
  * jack-waf2.patch
- Add 0001-fix-complation-on-arm.patch
* Wed Jul 24 2019 Dave Plater <davejplater@gmail.com>
- Disable link time optimization to fix crash see boo#1141762
* Mon Apr 15 2019 plater <davejplater@gmail.com>
- Added 0001-Make-jack_control-python2-3-compatible.patch from git
  to fix boo#1132458.
* Thu Sep 20 2018 davejplater@gmail.com
- Remove unnecessary requires for libjack0 and remove obsolete
  comments.
- Use %%license on "COPYING"
* Tue Sep 18 2018 Tom Mbrt <tom.mbrt@googlemail.com>
- Add upstream patch to fix return value check of mmap() (boo#1108981):
  fix-mmap-return-value-check.patch
* Thu Sep 13 2018 Tomáš Chvátal <tchvatal@suse.com>
- Update the waf code to the 2.0 series in order to work under
  python3.7 taken from upstream git:
  * jack-waf2.patch
* Sun Jan  7 2018 davejplater@gmail.com
- Build with _smp_mflags
* Fri Jan  5 2018 davejplater@gmail.com
- Split off libjacknet0 and libjackserver0 into subpackages.
* Thu Jan  4 2018 davejplater@gmail.com
- Update to version 1.9.12 and use python3 instead of python2 for
  the build.
- Removed jack-sparcv9.diff and jack-ppc64-long.patch, the file
  that is patched - linux/cycles.h no longer exists.
- Removed reproducible.patch, gcc6-fixes.diff and jack-fixgcc7.patch
  they are all now upstream.
- Upstream changes:
  * Various corrections in NetJack2 code.
  * Partial buffers can now be transmitted with libjacknet API.
  * Including S24_LE/BE formats to linux ALSA driver.
  * More robust shared memory allocator.
  * Correct CoreAudio devices aggregation code.
  * Waf and wscripts improvement and update.
  * New JackProxyDriver.
  * Various fixes in JACK MIDI code.
  * Fix return value of SetTimebaseCallback().
  * Correct netmanager latency reporting.
  * Implement new jack_port_rename and JackPortRenameCallback API.
  * Fix CPU hogging of the midi_thread().
  * Release audio devices when alsa_driver_new fails.
  * String management fix.
  * Correct JackDriver::Open : call to fGraphManager->SetBufferSize
  has to use current fEngineControl->fBufferSize value.
  * Use ARM neon intrinsics for AudioBufferMixdown.
  * Fix Netjack alignment.
  * Various wscript improvements and cleanup.
  * Fix initialization of several class variables.
  * Heap-allocate client matrix in topo sort.
  * Add a toggle command to transport utility, to allow toggling
  between play and stop state.
  * Avoid side effects from parsing of "version" option in jackd.
  * Allow firewire device be selected via -d.
  * Add ARM-NEON acceleration for all non-dithering sample
  conversion functions.
  * Add jack_simdtest utility.
  * Use Linux futex as JackSynchro.
  * Add autoclose option to jack_load.
  * Fix build with gcc-7.
  * Show hint when DBus device reservation fails.
  * Add support for internal session files.
* Wed Jul 19 2017 davejplater@gmail.com
- Modify jack-fixgcc7.patch in line with upstream.
* Sun Apr  2 2017 davejplater@gmail.com
- Fix gcc7 build failure with jack-fixgcc7.patch, sent to github
  jack2 issue#253
* Fri Apr 15 2016 tiwai@suse.de
- Fix the build failure with gcc6:
  gcc6-fixes.diff
* Sun Mar 20 2016 davejplater@gmail.com
- Use pkgconfig buildrequires and cleanup spec.
- BuildIgnore libiec61883 to allow Leap42 and earlier build again.
* Fri Mar 18 2016 bwiedemann@suse.com
- Add reproducible.patch to fix build-compare
* Tue May 26 2015 jkeil@suse.com
- Added libjack-devel to baselibs.conf
* Mon May 25 2015 plinnell@opensuse.org
- Enable 32bit build in baselibs.conf
* Sat Mar  7 2015 mpluskal@suse.com
- Replace celt with opus
  * remove jack-celt-build-fix.diff
* Sun Sep 21 2014 davejplater@gmail.com
- Update to release 1.9.10
- Removed patches jack-wafdocbuild.patch and aarch64.patch as they
  are now in upstream.
- Upstream changes:
  * Correct JackPortAudioDriver::Open : special case for ASIO drivers.
  * Correct JackEngine::NotifyGraphReorder : graph-order callback now notified after port latencies update.
  * netjack/opus: don't re-init en/decoders.
  * Use string ids in the alsa device list.
  * controlapi: fix double free on master switch.
  * netjack1/netone opus support.
  * netjack1/2 Opus: use only 2bytes for encoded-length.
  * wscript: add header defines and libs for example-clients/netsource.
  * fix duplicate prog.includes.
  * More robust channel mapping handling in JackCoreAudioDriver.
  * Add opus support to NetJack2.
  * jack_control: fix epr command.
  * Update JackCoreAudioDriver and JackCoreAudioAdapter with more recent API.
  * Devin Anderson patch for Jack/CoreMIDI duplicated messages.
  * Fix in ALSA adapter.
  * Fix alsa driver parameter order.
  * Control API: Enforce driver/internal parameter order.
  * Extend jack_control to have parameter reset commands.
  * Align buffers to 32 byte boundaries to allow AVX processing.
  * New jack_get_cycle_times() implementation from Fons Adriennsen.
  * Update waf.
  * [firewire] Introduce UpdateLatencies() in FFADO backend.
  * [firewire] Allow FFADO backend to change the buffer size.
  * Rework JackMessageBuffer.
  * POST_PACKED_STRUCTURE used for jack_latency_range_t type.
  * Remove JACK_32_64 flag, so POST_PACKED_STRUCTURE now always used.
  * Improve libjacknet master mode.
  * In control API, UNIX like sigset_t replaced by more abstract jackctl_sigmask_t * opaque struct.
  * Check server API callback from notification thread.
  * Use a time-out in notification channel write function.
  * Fix lock management in JackEngine.
  * A bit more robust JackMessageBuffer implementation (in progress).
  * Rename JackProcessSync in JackPosixProcessSync.
  * Fix NetJack2 initialisation bug.
  * Improve ShutDown in NetManager.
  * Correct ShutDown in JackInternalClient and JackLibClient.
  * Implement shutdown for in server clients.
  * Better time-out management in NetJack2.
  * More robust server/client protocol.
  * Factorize code the server/client request in JackRequestDecoder class.
  * Cleanup drivers and internals loading code.
  * jackctl_driver_params_parse API moved in public control.h.
  * More general drivers/internals loading model on Windows.
  * Fix library symbols export issue.
  * Adrian Knoth fix in midiseq.c.
* Fri May  2 2014 ohering@suse.de
- Enable firewire only for 12.1+ due to lack of libffado-devel
* Tue Jun 11 2013 dmueller@suse.com
- add aarch64.patch
* Thu Jun  6 2013 cdenicolo@suse.com
- license update:  GPL-2.0+ and LGPL-2.1+
  jack server is licensed under GPL-2.0+
* Thu Mar 28 2013 mmeister@suse.com
- Added url as source.
  Please see http://en.opensuse.org/SourceUrls
* Mon Feb  4 2013 davejplater@gmail.com
- Update to release 1.9.9.5 for bnc#801442
- Removed patches: jack-uc_regs.patch, jack-segfault.patch they are
  incorporated.
- Doxygen build doesn't work created jack-wafdocbuild.patch.
- Upstream changes :
  * Adrian Knoth fix in midiseq.c.
  * Fix library symbols export issue.
  * Cleanup drivers and internals loading code.
  * jackctl_driver_params_parse API moved in public control.h.
  * Factorize code the server/client request in JackRequestDecoder class.
  * More robust server/client protocol.
  * Better time-out management in NetJack2.
  * Improve ShutDown in NetManager.
  * Correct ShutDown in JackInternalClient and JackLibClient.
  * Fix NetJack2 initialisation bug. Add EndTime function.
  * Rename JackProcessSync in JackPosixProcessSync.
  * A bit more robust JackMessageBuffer implementation.
  * Check server API callback from notification thread.
  * Use a time-out in notification channel write function.
  * Fix lock management in JackEngine.
  * In control API, UNIX like sigset_t replaced by more abstract jackctl_sigmask_t * opaque struct.
  * Improve libjacknet master mode.
  * Remove JACK_32_64 flag, so POST_PACKED_STRUCTURE now always used. POST_PACKED_STRUCTURE used for jack_latency_range_t type.
  * Rework JackMessageBuffer.
  * [firewire] Introduce UpdateLatencies() in FFADO backend.
  * [firewire] Allow FFADO backend to change the buffer size.
  * Update waf.
  * New jack_get_cycle_times() implementation from Fons Adriennsen.
  * Align buffers to 32 byte boundaries to allow AVX processing.
  * Extend jack_control to have parameter reset commands.
  * Fix alsa driver parameter order.
  * Control API: Enforce driver/internal parameter order.
  * Fix in ALSA adapter.
  * Devin Anderson patch for Jack/CoreMIDI duplicated messages.
  * Change framework installation hierarchy for OSX Mountain Lion.
  * Update JackCoreAudioDriver and JackCoreAudioAdapter with more recent API.
  * jack_control: fix epr command.
  * Add opus support to NetJack2.
  * More robust channel mapping handling in JackCoreAudioDriver.
  * netjack1/netone opus support. controlapi: fix double free on master switch.
  * Use string ids in the alsa device list. netjack/opus: don't re-init en/decoders.
  * Correct JackPortAudioDriver::Open : special case for ASIO drivers.
  * waf: configure option for enforcing autostart method
  * ALSA devices reservation fixes.
* Wed Jun 27 2012 dvaleev@suse.com
- fix R_PPC64_ADDR32 fff85e94858 for symbol `' out of range
- fix jack_connect segfault
* Tue Apr 10 2012 klaussfreire@gmail.com
- Disable parallel build to limit resource usage and prevent hung
  build hosts.
* Sun Feb 26 2012 davejplater@gmail.com
- Update to version 1.9.8
- Remade jack-celt-build-fix.diff
- Upstream changes :
- Merge newer-midi branch (Devin Anderson redesign of the
  MIDI drivers: alsarawmidi, ffado, coremidi and winmme).
- Correction in jackdmp.cpp: notify_server_stop should be done
  after server destruction.
- Correct driver lifetime management.
- Add XRun detection in PortAudio driver.
- CELT code for NetJack2.
- Merge branch switch-master-port-registration-notifications:
  correct driver port registration.
- Libjacknet in progress.
- Correct MIDI in NetJack2.
- Correct OSX real-time thread setup.
- Correct rd_acquire in dbus code.
- Correct NetJack2 connection handling.
- SaveConnections/RestoreConnections in NetDriver and JackAudioDriver.
- Special version of jack_attach_shm/jack_release_shm on client
  side for POSIX shared memory, to solve a memory leak issue.
- Another round of code improvements to handle completely
  buggy Digidesign CoreAudio user-land driver.
- Special CATCH_CLOSE_EXCEPTION_RETURN to handle Close API calls.
- Add JACK_NETJACK_PORT and JACK_NETJACK_MULTICAST environment
  variables for NetJack2.
- NetJack2 now only send data on network only is ports are connected
  both sides.
- Fix for "starting two instances of same app in parallel does not
  work" bug.
- Enable explicit channel mapping in CoreAudio driver.
- New JackTimedDriver class to be used by JackDummyDriver,
  JackNetDriver and JackNetOneDriver classes.
- More robust code in synchronization primitives and JackMessageBuffer.
- More robust Control API implementation.
- Add jackctl_driver_get_type in Control API.
- Singleton behaviour for JackCoreMidiDriver and JackWinMMEDriver.
- John Emmas patch for DSP CPU computation.
- John Emmas Windows server launching patch.
- Fix jack_set_port_name API.
- Enable local access in NetJack2 code.
- Dynamic port management in JACK/CoreMidi bridge.
* Mon Feb 13 2012 dvaleev@suse.com
- ppc64 doesn't have uc_regs
* Tue Oct 18 2011 adrian@suse.de
- drop jack-CAS.diff patch to fix non ia32/x86_64/ppc build,
  seems to be fixed upstream similar
* Wed Sep  7 2011 davejplater@gmail.com
- Enabled dbus support requested on multimedia list
- Disabled engine profiling
* Tue Sep  6 2011 davejplater@gmail.com
- Removed malfunctioning services
* Thu May 19 2011 davejplater@gmail.com
- Update to version 1.9.7
- Upstream changes :
  * Sync JackAlsaDriver::alsa_driver_check_card_type with JACK1 backend.
  * Improve backend error handling: fatal error returned by Read/Write
  now cause a Process failure (so a thread exit for blocking backends).
  * Recoverable ones (XRuns..) are now treated internally in ALSA and
  FFADO backends.
  * In jackdmp.cpp, jackctl_setup_signals moved before jackctl_server_start.
  * Correct dummy driver.
  * Adrian Knoth jack_lsp patch.
  * Remove JackPortIsActive flag.
  * New latency API implementation.
  * ComputeTotalLatencies now a client/server call.
  * Add latent test client for latency API.
  * Also print playback and capture latency in jack_lsp.
  * jack_client_has_session_callback implementation.
  * Check requested buffer size and limit to 1..8192  avoids weird
  behaviour caused by jack_bufsize foobar.
  * jack_port_type_get_buffer_size implementation.
  * Stop using alloca and allocate buffer on the heap for alsa_io.
  * Rename jdelay to jack_iodelay as per Fons' request.
  * Call buffer size callback in activate (actually this is done on
  client side in the RT thread Init method).
  * Add jack_midi_dump client. Synchronize net JACK1 with JACK1 version.
  * Synchronize jack_connect/jack_disconnect with JACK1 version.
  * Correct JackNetMaster::SetBufferSize.
  * Use jack_default_audio_sample_t instead of float consistently,
  fix ticket #201. -X now allows to add several slave backends, add -I
  to load several internal clients.
  * Rework internal slave driver management, JackServerGlobals now
  handle same parameters as jackdmp.
  * Correct JackEngine::NotifyGraphReorder, update JackDebugClient
  with latest API.
  * Devin Anderson server-ctl-proposal branch merged on trunk: improved
  control API, slave backend reworked.
  * Implement renaming in JackDriver::Open to avoid name collision.
  * Correct alsa_driver_restart (thanks Devin Anderson).
  * Correction of jack_connect/jack_disconnect: use of jack_activate
  and volatile keyword for thread shared variable.
  * Correction of JackNetOneDriver for latest CELT API.
  * Synchronize JackWeakAPI.cpp with new APIs.
* Fri Dec 10 2010 davejplater@gmail.com
- Added jack-celt-build-fix.diff to fix jack build with celt-0.9.1
* Tue Nov  9 2010 davejplater@gmail.com
- Update to version 1.9.6
- Upstream changes :
  * Improve JackCoreAudioDriver and JackCoreAudioAdapter : when no
  devices are described, takes default input and output and
  aggregate them.
  * Correct JackGraphManager::DeactivatePort.
  * Correct JackMachServerChannel::Execute : keep running even in
  error cases.
  * Raise JACK_PROTOCOL_VERSION number. Arnold Krille firewire patch.
  * Fix some file header to have library side code use LGPL.
  * ffado-portname-sync.patch from ticket #163 applied.
  * Remove call to exit in library code.
  * Make jack_connect/jack_disconnect wait for effective port
  connection/disconnection.
  * Add tests to validate intclient.h API.
  * On Linux, inter-process synchronization primitive switched to
  POSIX semaphore.
  * In JackCoreAudioDriver, move code called in MeasureCallback to be
  called once in IO thread.
  * David Garcia Garzon netone patch.
  * Fix from Fernando Lopez-Lezcano for compilation on fc13.
  * Fix JackPosixSemaphore::TimedWait : same behavior as
  JackPosixSemaphore::Wait regarding EINTR.
  * David Garcia Garzon unused_pkt_buf_field_jack2 netone patch.
  * Arnold Krille firewire snooping patch.
  * Jan Engelhardt patch for get_cycles on SPARC.
  * Adrian Knoth hurd.patch, kfreebsd-fix.patch and
  alpha_ia64-sigsegv.patch from ticket 177.
  * Adrian Knoth fix for linux cycle.h (ticket 188).
  * In JackCoreAudioDriver, fix an issue when no value is given for
  input.
* Wed Jul  7 2010 davejplater@gmail.com
- Enable ffado firewire support
* Wed Jul  7 2010 jengelh@medozas.de
- Provide missing functions to enable SPARC compilation
* Tue Jul  6 2010 jengelh@medozas.de
- Build fix: make sure $RPM_OPT_FLAGS is in CFLAGS (SPARC _needs_
  its -march=ultrasparc from prjconf to make atomic ops available)
- Strip remaining CFLAGS since they are the same as in prjconf
* Thu Apr 29 2010 ro@suse.de
- use _smp_mflags instead of -j'percent'{jobs}
* Tue Apr  6 2010 davejplater@gmail.com
- Update to jack-1.9.5 which now has support for distributing audio
  processing across a network.
- Removed jack-shmat-check-fix.diff.
* Fri Feb 19 2010 coolo@novell.com
- remove libfreebob dependency
* Wed Feb 17 2010 tiwai@suse.de
- minor spec file clean-ups
* Tue Feb  9 2010 edogawa@aon.at
- update to 0.118.0
- don't use gcc4 patch and all that autotool stuff before ./configure
- fixed dependencies (missing versions)
* Fri Dec 18 2009 jengelh@medozas.de
- add baselibs.conf as a source
* Tue Sep 22 2009 tiwai@suse.de
- fix minor strdup memory leaks (bnc#539096)
* Sun Jun 21 2009 coolo@novell.com
- fix requires of devel package (libjack requires libsamplerate now)
* Fri Jun 19 2009 tiwai@suse.de
- add libsndfile and libsamplerate to buildrequires to support
  netjack driver
* Fri Jun 19 2009 tiwai@suse.de
- fix mismatching pclose() (bnc#514072)
* Mon Apr 20 2009 tiwai@suse.de
- updated to version 0.116.2:
  * Stable version update since 0.109.2: quite lots of fixes and
    updates.  See
    http://jackaudio.org/node/20
    http://jackaudio.org/node/21
    http://jackaudio.org/node/22
* Wed Dec 10 2008 olh@suse.de
- use Obsoletes: -XXbit only for ppc64 to help solver during distupgrade
  (bnc#437293)
* Thu Dec  4 2008 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Mon Oct 13 2008 tiwai@suse.de
- Fix the compile warnings regarding the check of shmat() return
  value (bnc#434725)
* Tue Apr 29 2008 tiwai@suse.de
- add --disable-static explicitly to fix build with new autoconf
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Thu Jan 31 2008 tiwai@suse.de
- deprecate run_ldconfig
- updated to version 0.109.2:
  * fix use of popen() to work on systems that reset PATH
  * USX2Y driver updates
  * revert name of ALSA audio backend to "alsa_pcm"
  * add disgusting kludge so that "ALSA:...." port names continue
    to work
* Mon Jan 28 2008 tiwai@suse.de
- rename packages to follow the shlib packaging policy (to avoid
  conflict with packman).
* Tue Jan 15 2008 tiwai@suse.de
- updated to version 0.109.9:
  * API changes:
  * add jack_thread_wait API
  * remove port_(un)lock functions
  * add new time APIs
  * add port aliases
  * add new client registration callback
  * add port connect callback
  * ALSA: fix for use of snd_pcm_link
  * ALSA: hardware jack-midi support
  * ALSA: fix for enabling big-endian 16bit format discovery
  * FreeBoB: fix deallocation segfault
  * FireWire: add 'firewire' backend for use with FFADO
  * OSS: add support for proper triggering in OSS driver when in
    full duplex mode
  * ALSA: fix illegal use of ALSA API
  * OSS: disable software mixing and samplerate conversions on
    OSS 4.x
  * CoreAudio: fix sample rate management
  * add JACK_PROMISCUOUS_SERVER handling
  * make /dev/shm the default tmpdir
  * add -Z flag to cancel zombification on timeout
  * add per-port update total latency
  * increment default watchdog timeout to 10sec
- remove obsolete README.SuSE
* Wed Oct 31 2007 tiwai@suse.de
- don't build with POSIX SHM (#337972)
* Mon Apr 16 2007 tiwai@suse.de
- remove md5_loc.h with RSA license which is incopmatile with
  GPL (#264837)
* Tue Apr 10 2007 tiwai@suse.de
- fix post and postun for libjack.
* Tue Apr  3 2007 tiwai@suse.de
- split to libjack and jack-freebob sub packages to reduce
  library dependencies.
* Tue Mar 27 2007 tiwai@suse.de
- added freebob support.
* Mon Mar 26 2007 tiwai@suse.de
- updated to version 0.103.0:
  * Fixed broken --disable-freebob config option.
  * Jack now reads the global config file.
  * Fix for jack_midiseq.
  * For for HPET code to use 32-bit reads on all platforms,
    for atomicity reasons.
  * Directly accessing Jack port internal structure is forbidden.
  * Minor fixes for midi support.
  * Fix for freebob driver crash.
  * Fix for alsa usb interleave_skip handling.
  * Fix for memory leak in ringbuffer.
  * Fix for shutdown segfault fix.
* Tue Jan  9 2007 tiwai@suse.de
- use /dev/shm as the default tmp dir (#231072)
* Thu Oct 12 2006 tiwai@suse.de
- updated to version 0.102.20:
  * Make "alsa" the default backend when both it and "freebob" are
    present.
  * JACK MIDI patch -- Experimental!
  * allow use of h/w devices that only support big-endian formats.
  * jack_lsp now has a -L flag to show "total latency" values
  * ALSA driver no longer requires access to a control device
  * jack_lsp -t shows port type
  * jackd will exit if -R is used but realtime is unavailable
  * halve JACK_THREAD_STACK_TOUCH to 500000
  * increase default --port-max option from 128 to 256
  * Many bug fixes
- fix compilation of usx2y.c
* Wed Sep 20 2006 tiwai@suse.de
- updated to version 0.101.1:
  * Freebob backend support
  * Mactel platform fixes
  * Unplug support of USB soundcard
  * dynsmid option
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Dec 12 2005 tiwai@suse.de
- disable the arch optimization (#138070).
* Sun Nov 13 2005 schwab@suse.de
- Fix use of atomic builtins.
* Wed Oct 12 2005 tiwai@suse.de
- removed glib* from neededfobuild.
* Wed Oct  5 2005 tiwai@suse.de
- added flac and flac-devel to neededforbuild (required by the new
  libsndfile).
* Tue Oct  4 2005 tiwai@suse.de
- updated to version 0.100.0.
* Thu Mar 31 2005 coolo@suse.de
- avoid ancient compiler options no longer supported by gcc4
* Thu Jan 27 2005 tiwai@suse.de
- Fix README.SuSE, removed README.SuSE_de (bug #50106)
* Tue Nov  9 2004 tiwai@suse.de
- updated to version 0.99.0.
- moved manpage to the main package (bug #47723).
* Thu Sep 23 2004 tiwai@suse.de
- fixed segfault by signal.
- fixed segfault when no shm access is available.
- use different socket files for each pid (bug #45816).
* Thu Aug 12 2004 ro@suse.de
- added libpng to neededforbuild (for doxygen)
* Fri Aug  6 2004 adrian@suse.de
- revert linking of libjack against libreadline and libncurses.
  it was introduced due to a broken configure check and is only
  needed for one example binary
* Thu Aug  5 2004 tiwai@suse.de
- updated to 0.98.1 with NPTL fixes.
- regenerated the last ppc patch for the newer version.
* Sun Mar  7 2004 meissner@suse.de
- Do not use the strange exception handler construct on ppc/linux,
  it does not work on Linux and breaks ppc64.
* Mon Feb 16 2004 tiwai@suse.de
- build as non-root.
* Wed Jan 14 2004 tiwai@suse.de
- updated to version 0.94.0.
* Tue Nov 18 2003 tiwai@suse.de
- updated to version 0.90.0.
* Thu Aug 28 2003 tiwai@suse.de
- better fix (define explicitly the value) for the last one.
- fixed the remaining bug of half-duplex mode.
- fixed the build on s390.
* Thu Aug 28 2003 tiwai@suse.de
- fixed the definition of UINT32_MAX for C++.
* Wed Aug 27 2003 tiwai@suse.de
- use C99 style ints.
- fixed the transport bug.
- fixed the bug of alsa driver in half-duplex mode.
* Mon Aug 25 2003 tiwai@suse.de
- updated to 0.79.0.
  patches have been integrated.
* Fri Aug 15 2003 tiwai@suse.de
- fixed the occasional crash with ALSA plug layer.
- support asymmetric pcm streams.
* Mon Aug 11 2003 tiwai@suse.de
- updated to version 0.75.0.
* Tue Jul 22 2003 tiwai@suse.de
- updated to version 0.74.1.
* Wed Jul  2 2003 tiwai@suse.de
- updated to version 0.72.4.
* Thu Jun 12 2003 kukuk@suse.de
- Add docdir to filelist
* Wed May 28 2003 ro@suse.de
- add man-pages and .la files to devel filelist
* Tue Apr  1 2003 tiwai@suse.de
- updated to ver.0.66.3.
* Tue Mar 11 2003 tiwai@suse.de
- added README.SuSE and README.SuSE_de to explain the real-time
  mode of jack.
* Thu Feb 13 2003 pthomas@suse.de
- Compile with all usefull warn options.
- Fix all places where the compiler warns, including
  disabling ununsed static functions by '#if 0'.
* Mon Feb 10 2003 tiwai@suse.de
- updated to version 0.50.0.
  all patches have been integrated to the mainstream.
* Fri Jan 17 2003 tiwai@suse.de
- updated to ver.0.44.0.
- added *.la file to the devel package.
- removed double document files.
- removed plugins from provides.
* Tue Jan 14 2003 nadvornik@suse.cz
- fixed multi-line string literals
* Thu Nov 28 2002 aj@suse.de
- Add gcc-c++ to needforbuild since the package needs a C++ preprocessor.
* Tue Nov 26 2002 tiwai@suse.de
- updated ver.0.40.1.
  libsndfile patch was removed.
- added %%run_ldconfig.
* Wed Aug  7 2002 tiwai@suse.de
- jack ver.0.37.2.  including minor bug fixes for alsa.
* Wed Jun 26 2002 tiwai@suse.de
- fixed an example client for the new libsndfile.
* Tue Jun 25 2002 tiwai@suse.de
- updated to version 0.34.0.  (cvs 2002.06.25)
- added doxygen to neededtobuild to generate references.
* Tue Apr 16 2002 tiwai@suse.de
- updated to version 0.26.1.
- fixed build on non-intel architectures again.
* Thu Apr 11 2002 tiwai@suse.de
- fixed build on non-intel architectures.
- fixed compile warnings with gcc3.1.
* Wed Apr 10 2002 tiwai@suse.de
- initial version: cvs at 2002.04.10.
